@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use crate::spec::transform::TransformSpecTrait;
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
@@ -36,7 +28,6 @@ unsupported_transforms!(
     DensityTransformSpec,
     DotbinTransformSpec,
     FlattenTransformSpec,
-    FoldTransformSpec,
     ForceTransformSpec,
     GeojsonTransformSpec,
     GeopathTransformSpec,
@@ -44,7 +35,6 @@ unsupported_transforms!(
     GeoshapeTransformSpec,
     GraticuleTransformSpec,
     HeatmapTransformSpec,
-    IdentifierTransformSpec,
     IsocontourTransformSpec,
     KdeTransformSpec,
     Kde2dTransformSpec,
@@ -55,7 +45,6 @@ unsupported_transforms!(
     PackTransformSpec,
     PartitionTransformSpec,
     PieTransformSpec,
-    PivotTransformSpec,
     QuantileTransformSpec,
     RegressionTransformSpec,
     ResolvefilterTransformSpec,
